@@ -174,8 +174,3 @@ class ActionPlan(object):
     @property
     def is_not_empty(self):
         return not self.is_empty
-
-    def remove_actions_on_unhandled_hosts(self, handled_hosts, components):
-        actions_on_handled_hosts = [
-            action for action in self.actions if components[action.uri].host_uri in handled_hosts]
-        self.actions = tuple(sorted(actions_on_handled_hosts))
