@@ -36,3 +36,6 @@ STANDALONE_SERVICE_RANK = 49152
 
 SSH_POLL_DELAY = 5
 SSH_POLL_MAX_SECONDS_DEFAULT = 120
+
+TEN_MINUTES_IN_SECONDS = 60 * 10
+MAX_ALLOWED_AGE_OF_STATE_IN_SECONDS = TEN_MINUTES_IN_SECONDS
