@@ -23,6 +23,7 @@ import time
 import filecmp
 import shutil
 import yaml
+import socket
 
 import hostexpand.HostExpander
 
@@ -36,7 +37,9 @@ sys.path.append('/etc/yadtshell')
 
 DEFAULT_LOG_DIR = '/tmp/logs/yadtshell'
 USER_INFO = get_user_info()
-OUTPUT_DIR = os.path.expanduser('~%s/.yadtshell' % USER_INFO['user'])
+OUTPUT_DIR = os.path.expanduser('~%s/.yadtshell/%s' % (USER_INFO['user'], socket.gethostname()))
+reboot_disabled = False
+
 
 OUT_DIR = os.path.join(OUTPUT_DIR, 'tmp', os.getcwd().lstrip('/'))
 TODAY = None
@@ -174,7 +177,8 @@ def load_settings_and_create_dirs(log_to_file=True):
         os.makedirs(OUT_DIR)
     except OSError as e:
         if e.errno != 17:   # 17: file exists
-            root_logger.critical('cannot write to out dir %s' % OUT_DIR)
+            root_logger.critical('Cannot create cache directory %s on %s'
+                                 % (OUT_DIR, USER_INFO['yadt_host']))
             root_logger.exception(e)
             sys.exit(1)
         pass
@@ -195,7 +199,7 @@ def load_settings_and_create_dirs(log_to_file=True):
     else:
         ybc = DummyBroadcaster()
 
-    LOG_DIR = os.path.join(LOG_DIR_PREFIX, TODAY)
+    LOG_DIR = os.path.join(LOG_DIR_PREFIX, TODAY, TARGET_SETTINGS['name'])
     try:
         os.makedirs(LOG_DIR)
     except OSError as e:
