@@ -16,7 +16,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
+from __future__ import (absolute_import, print_function)
 
 import glob
 import os
@@ -57,14 +57,16 @@ def status_cb(protocol=None):
 
 def query_status(component_name, pi=None):
     p = yadtshell.twisted.YadtProcessProtocol(
-        component_name, '/usr/bin/yadt-status', pi)
+        component_name, '/usr/bin/yadt-status', pi, out_log_level=logging.NOTSET)
     p.deferred.name = component_name
     cmd = shlex.split(yadtshell.settings.SSH) + [component_name]
     reactor.spawnProcess(p, cmd[0], cmd, os.environ)
     return p.deferred
 
 
-def handle_unreachable_host(failure, components):
+def handle_failing_status(failure, components):
+    if failure.value.exitCode == 127:
+        logger.critical('No yadt-minion installed on remote host %s' % failure.value.component)
     if failure.value.exitCode == 255:
         logger.critical(
             'ssh: cannot reach %s\n\t passwordless ssh not configured? network problems?' %
@@ -76,7 +78,17 @@ def handle_unreachable_host(failure, components):
     return failure
 
 
+def write_host_data_to_file(host, host_data):
+    host = host.replace("host://", "")
+    file_path = "%s.%s.status" % (yadtshell.settings.log_file, host)
+    logger.debug("Status of %s is at %s" % (host, file_path))
+    with open(file_path, "w") as status_file:
+        status_file.write(host_data)
+
+
 def create_host(protocol, components):
+    write_host_data_to_file(protocol.component, protocol.data)
+
     try:
         data = json.loads(protocol.data)
     except Exception, e:
@@ -145,6 +157,8 @@ def initialize_services(host, components):
 
 def get_service_class_from_loaded_modules(service_class_name):
     for module_name in sys.modules.keys()[:]:
+        if module_name.startswith("six.moves"):
+            continue  # six.moves is horrible and inspecting it causes a crash
         for classname, service_class in inspect.getmembers(sys.modules[module_name], inspect.isclass):
             if classname == service_class_name:
                 return service_class
@@ -330,7 +344,7 @@ def status(hosts=None, include_artefacts=True, **kwargs):
         all_ok = True
         for ok, response in responses:
             if not ok:
-                logger.error(response)
+                logger.debug("Found errored status response: %s" % response)
                 all_ok = False
         if not all_ok:
             raise Exception('errors occured during status')
@@ -379,13 +393,13 @@ def status(hosts=None, include_artefacts=True, **kwargs):
             yadtshell.settings.HOST: _open_component_file('hosts'),
         }
         for component in components.values():
-            print >> component_files[component.type], component.uri
+            component_files[component.type].write(component.uri + "\n")
 
         for f in component_files.values():
             f.close()
 
         f = _open_component_file('current_state.components')
-        pickle.dump(components, f)
+        pickle.dump(components, f, pickle.HIGHEST_PROTOCOL)
         f.close()
 
         groups = []
@@ -426,8 +440,8 @@ def status(hosts=None, include_artefacts=True, **kwargs):
             groups, tracking_id=yadtshell.settings.tracking_id)
 
         status_line = yadtshell.util.get_status_line(components)
-        logger.debug('\nstatus: %s' % status_line)
-        print status_line
+        logger.debug('status: %s' % status_line)
+        print(status_line)
         f = open(os.path.join(yadtshell.settings.OUT_DIR, 'statusline'), 'w')
         f.write('\n'.join(['', status_line]))
         f.close()
@@ -450,7 +464,7 @@ def status(hosts=None, include_artefacts=True, **kwargs):
     def query_and_initialize_host(host):
         deferred = query_status(host, pi)
         deferred.addCallbacks(callback=create_host, callbackArgs=[components],
-                              errback=handle_unreachable_host, errbackArgs=[components])
+                              errback=handle_failing_status, errbackArgs=[components])
 
         deferred.addCallback(initialize_services, components)
         deferred.addCallback(add_local_state)
